from typing import Text

from boto.connection import AWSAuthConnection
from boto.regioninfo import RegionInfo

from .connection import S3Connection

class S3RegionInfo(RegionInfo):
    def connect(
        self,
        name: Text | None = ...,
        endpoint: str | None = ...,
        connection_cls: type[AWSAuthConnection] | None = ...,
        **kw_params,
    ) -> S3Connection: ...

def regions() -> list[S3RegionInfo]: ...
def connect_to_region(region_name: Text, **kw_params): ...



from typing import Any

class BucketLogging:
    target: Any
    prefix: Any
    grants: Any
    def __init__(self, target: Any | None = ..., prefix: Any | None = ..., grants: Any | None = ...) -> None: ...
    def add_grant(self, grant): ...
    def startElement(self, name, attrs, connection): ...
    def endElement(self, name, value, connection): ...
    def to_xml(self): ...



from setuptools import setup

name = "types-boto"
description = "Typing stubs for boto"
long_description = '''
## Typing stubs for boto

This is a PEP 561 type stub package for the `boto` package.
It can be used by type-checking tools like mypy, PyCharm, pytype etc. to check code
that uses `boto`. The source for this package can be found at
https://github.com/python/typeshed/tree/master/stubs/boto. All fixes for
types and metadata should be contributed there.

See https://github.com/python/typeshed/blob/master/README.md for more details.
This package was generated from typeshed commit `c3907ab26b1c75bc19163aa828d1197ae8640127`.
'''.lstrip()

setup(name=name,
      version="2.49.8",
      description=description,
      long_description=long_description,
      long_description_content_type="text/markdown",
      url="https://github.com/python/typeshed",
      project_urls={
          "GitHub": "https://github.com/python/typeshed",
          "Changes": "https://github.com/typeshed-internal/stub_uploader/blob/main/data/changelogs/boto.md",
          "Issue tracker": "https://github.com/python/typeshed/issues",
          "Chat": "https://gitter.im/python/typing",
      },
      install_requires=['types-six'],
      packages=['boto-stubs'],
      package_data={'boto-stubs': ['__init__.pyi', 'auth.pyi', 'auth_handler.pyi', 'compat.pyi', 'connection.pyi', 'ec2/__init__.pyi', 'elb/__init__.pyi', 'exception.pyi', 'kms/__init__.pyi', 'kms/exceptions.pyi', 'kms/layer1.pyi', 'plugin.pyi', 'regioninfo.pyi', 's3/__init__.pyi', 's3/acl.pyi', 's3/bucket.pyi', 's3/bucketlistresultset.pyi', 's3/bucketlogging.pyi', 's3/connection.pyi', 's3/cors.pyi', 's3/deletemarker.pyi', 's3/key.pyi', 's3/keyfile.pyi', 's3/lifecycle.pyi', 's3/multidelete.pyi', 's3/multipart.pyi', 's3/prefix.pyi', 's3/tagging.pyi', 's3/user.pyi', 's3/website.pyi', 'utils.pyi', 'METADATA.toml']},
      license="Apache-2.0 license",
      classifiers=[
          "License :: OSI Approved :: Apache Software License",
          "Typing :: Stubs Only",
      ]
)



from typing import Any, Text

from .bucketlistresultset import BucketListResultSet
from .connection import S3Connection
from .key import Key

class S3WebsiteEndpointTranslate:
    trans_region: dict[str, str]
    @classmethod
    def translate_region(cls, reg: Text) -> str: ...

S3Permissions: list[str]

class Bucket:
    LoggingGroup: str
    BucketPaymentBody: str
    VersioningBody: str
    VersionRE: str
    MFADeleteRE: str
    name: Text
    connection: S3Connection
    key_class: type[Key]
    def __init__(self, connection: S3Connection | None = ..., name: Text | None = ..., key_class: type[Key] = ...) -> None: ...
    def __iter__(self): ...
    def __contains__(self, key_name) -> bool: ...
    def startElement(self, name, attrs, connection): ...
    creation_date: Any
    def endElement(self, name, value, connection): ...
    def set_key_class(self, key_class): ...
    def lookup(self, key_name, headers: dict[Text, Text] | None = ...): ...
    def get_key(
        self,
        key_name,
        headers: dict[Text, Text] | None = ...,
        version_id: Any | None = ...,
        response_headers: dict[Text, Text] | None = ...,
        validate: bool = ...,
    ) -> Key: ...
    def list(
        self,
        prefix: Text = ...,
        delimiter: Text = ...,
        marker: Text = ...,
        headers: dict[Text, Text] | None = ...,
        encoding_type: Any | None = ...,
    ) -> BucketListResultSet: ...
    def list_versions(
        self,
        prefix: str = ...,
        delimiter: str = ...,
        key_marker: str = ...,
        version_id_marker: str = ...,
        headers: dict[Text, Text] | None = ...,
        encoding_type: Text | None = ...,
    ) -> BucketListResultSet: ...
    def list_multipart_uploads(
        self,
        key_marker: str = ...,
        upload_id_marker: str = ...,
        headers: dict[Text, Text] | None = ...,
        encoding_type: Any | None = ...,
    ): ...
    def validate_kwarg_names(self, kwargs, names): ...
    def get_all_keys(self, headers: dict[Text, Text] | None = ..., **params): ...
    def get_all_versions(self, headers: dict[Text, Text] | None = ..., **params): ...
    def validate_get_all_versions_params(self, params): ...
    def get_all_multipart_uploads(self, headers: dict[Text, Text] | None = ..., **params): ...
    def new_key(self, key_name: Any | None = ...): ...
    def generate_url(
        self,
        expires_in,
        method: str = ...,
        headers: dict[Text, Text] | None = ...,
        force_http: bool = ...,
        response_headers: dict[Text, Text] | None = ...,
        expires_in_absolute: bool = ...,
    ): ...
    def delete_keys(self, keys, quiet: bool = ..., mfa_token: Any | None = ..., headers: dict[Text, Text] | None = ...): ...
    def delete_key(
        self, key_name, headers: dict[Text, Text] | None = ..., version_id: Any | None = ..., mfa_token: Any | None = ...
    ): ...
    def copy_key(
        self,
        new_key_name,
        src_bucket_name,
        src_key_name,
        metadata: Any | None = ...,
        src_version_id: Any | None = ...,
        storage_class: str = ...,
        preserve_acl: bool = ...,
        encrypt_key: bool = ...,
        headers: dict[Text, Text] | None = ...,
        query_args: Any | None = ...,
    ): ...
    def set_canned_acl(
        self, acl_str, key_name: str = ..., headers: dict[Text, Text] | None = ..., version_id: Any | None = ...
    ): ...
    def get_xml_acl(self, key_name: str = ..., headers: dict[Text, Text] | None = ..., version_id: Any | None = ...): ...
    def set_xml_acl(
        self,
        acl_str,
        key_name: str = ...,
        headers: dict[Text, Text] | None = ...,
        version_id: Any | None = ...,
        query_args: str = ...,
    ): ...
    def set_acl(self, acl_or_str, key_name: str = ..., headers: dict[Text, Text] | None = ..., version_id: Any | None = ...): ...
    def get_acl(self, key_name: str = ..., headers: dict[Text, Text] | None = ..., version_id: Any | None = ...): ...
    def set_subresource(
        self, subresource, value, key_name: str = ..., headers: dict[Text, Text] | None = ..., version_id: Any | None = ...
    ): ...
    def get_subresource(
        self, subresource, key_name: str = ..., headers: dict[Text, Text] | None = ..., version_id: Any | None = ...
    ): ...
    def make_public(self, recursive: bool = ..., headers: dict[Text, Text] | None = ...): ...
    def add_email_grant(self, permission, email_address, recursive: bool = ..., headers: dict[Text, Text] | None = ...): ...
    def add_user_grant(
        self, permission, user_id, recursive: bool = ..., headers: dict[Text, Text] | None = ..., display_name: Any | None = ...
    ): ...
    def list_grants(self, headers: dict[Text, Text] | None = ...): ...
    def get_location(self): ...
    def set_xml_logging(self, logging_str, headers: dict[Text, Text] | None = ...): ...
    def enable_logging(
        self, target_bucket, target_prefix: str = ..., grants: Any | None = ..., headers: dict[Text, Text] | None = ...
    ): ...
    def disable_logging(self, headers: dict[Text, Text] | None = ...): ...
    def get_logging_status(self, headers: dict[Text, Text] | None = ...): ...
    def set_as_logging_target(self, headers: dict[Text, Text] | None = ...): ...
    def get_request_payment(self, headers: dict[Text, Text] | None = ...): ...
    def set_request_payment(self, payer: str = ..., headers: dict[Text, Text] | None = ...): ...
    def configure_versioning(
        self, versioning, mfa_delete: bool = ..., mfa_token: Any | None = ..., headers: dict[Text, Text] | None = ...
    ): ...
    def get_versioning_status(self, headers: dict[Text, Text] | None = ...): ...
    def configure_lifecycle(self, lifecycle_config, headers: dict[Text, Text] | None = ...): ...
    def get_lifecycle_config(self, headers: dict[Text, Text] | None = ...): ...
    def delete_lifecycle_configuration(self, headers: dict[Text, Text] | None = ...): ...
    def configure_website(
        self,
        suffix: Any | None = ...,
        error_key: Any | None = ...,
        redirect_all_requests_to: Any | None = ...,
        routing_rules: Any | None = ...,
        headers: dict[Text, Text] | None = ...,
    ): ...
    def set_website_configuration(self, config, headers: dict[Text, Text] | None = ...): ...
    def set_website_configuration_xml(self, xml, headers: dict[Text, Text] | None = ...): ...
    def get_website_configuration(self, headers: dict[Text, Text] | None = ...): ...
    def get_website_configuration_obj(self, headers: dict[Text, Text] | None = ...): ...
    def get_website_configuration_with_xml(self, headers: dict[Text, Text] | None = ...): ...
    def get_website_configuration_xml(self, headers: dict[Text, Text] | None = ...): ...
    def delete_website_configuration(self, headers: dict[Text, Text] | None = ...): ...
    def get_website_endpoint(self): ...
    def get_policy(self, headers: dict[Text, Text] | None = ...): ...
    def set_policy(self, policy, headers: dict[Text, Text] | None = ...): ...
    def delete_policy(self, headers: dict[Text, Text] | None = ...): ...
    def set_cors_xml(self, cors_xml, headers: dict[Text, Text] | None = ...): ...
    def set_cors(self, cors_config, headers: dict[Text, Text] | None = ...): ...
    def get_cors_xml(self, headers: dict[Text, Text] | None = ...): ...
    def get_cors(self, headers: dict[Text, Text] | None = ...): ...
    def delete_cors(self, headers: dict[Text, Text] | None = ...): ...
    def initiate_multipart_upload(
        self,
        key_name,
        headers: dict[Text, Text] | None = ...,
        reduced_redundancy: bool = ...,
        metadata: Any | None = ...,
        encrypt_key: bool = ...,
        policy: Any | None = ...,
    ): ...
    def complete_multipart_upload(self, key_name, upload_id, xml_body, headers: dict[Text, Text] | None = ...): ...
    def cancel_multipart_upload(self, key_name, upload_id, headers: dict[Text, Text] | None = ...): ...
    def delete(self, headers: dict[Text, Text] | None = ...): ...
    def get_tags(self): ...
    def get_xml_tags(self): ...
    def set_xml_tags(self, tag_str, headers: dict[Text, Text] | None = ..., query_args: str = ...): ...
    def set_tags(self, tags, headers: dict[Text, Text] | None = ...): ...
    def delete_tags(self, headers: dict[Text, Text] | None = ...): ...
